"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    daily_reports_only: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of  FindingsReportSummary  objects that contain analysis results for all profiling groups in your AWS account.

    Args:
        daily_reports_only(bool, optional): A Boolean value indicating whether to only return reports from daily profiles. If set to True, only analysis data from daily profiles is returned. If set to False, analysis data is returned from smaller time windows (for example, one hour). Defaults to None.
        max_results(int, optional): The maximum number of results returned by  GetFindingsReportAccountSummary in paginated output. When this parameter is used, GetFindingsReportAccountSummary only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another GetFindingsReportAccountSummary request with the returned nextToken value. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated GetFindingsReportAccountSummary request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.   This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.finding_report.account_summary.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.finding_report.account_summary.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="get_findings_report_account_summary",
        op_kwargs={
            "dailyReportsOnly": daily_reports_only,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, name: str, event_bus_name: str = None, force: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified rule. Before you can delete the rule, you must remove all targets, using RemoveTargets. When you delete a rule, incoming events might continue to match to the deleted rule. Allow a short period of time for changes to take effect. If you call delete rule multiple times for the same rule, all calls will succeed. When you call delete rule for a non-existent custom eventbus, ResourceNotFoundException is returned. Managed rules are rules created and managed by another AWS service on your behalf. These rules are created by those other AWS services to support functionality in those services. You can delete these rules using the Force option, but you should do so only if you are sure the other service is not still using that rule.

    Args:
        name(str): The name of the rule.
        event_bus_name(str, optional): The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used. Defaults to None.
        force(bool, optional): If this is a managed rule, created by an AWS service on your behalf, you must specify Force as True to delete the rule. This parameter is ignored for rules that are not managed rules. You can check whether a rule is a managed rule by using DescribeRule or ListRules and checking the ManagedBy field of the response. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_rule",
        op_kwargs={"Name": name, "EventBusName": event_bus_name, "Force": force},
    )


async def describe(hub, ctx, name: str, event_bus_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified rule. DescribeRule does not list the targets of a rule. To see the targets associated with a rule, use ListTargetsByRule.

    Args:
        name(str): The name of the rule.
        event_bus_name(str, optional): The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_rule",
        op_kwargs={"Name": name, "EventBusName": event_bus_name},
    )


async def disable(hub, ctx, name: str, event_bus_name: str = None) -> None:
    r"""
    **Autogenerated function**

    Disables the specified rule. A disabled rule won't match any events, and won't self-trigger if it has a schedule expression. When you disable a rule, incoming events might continue to match to the disabled rule. Allow a short period of time for changes to take effect.

    Args:
        name(str): The name of the rule.
        event_bus_name(str, optional): The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.disable(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.disable name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="disable_rule",
        op_kwargs={"Name": name, "EventBusName": event_bus_name},
    )


async def enable(hub, ctx, name: str, event_bus_name: str = None) -> None:
    r"""
    **Autogenerated function**

    Enables the specified rule. If the rule does not exist, the operation fails. When you enable a rule, incoming events might not immediately start matching to a newly enabled rule. Allow a short period of time for changes to take effect.

    Args:
        name(str): The name of the rule.
        event_bus_name(str, optional): The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.enable(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.enable name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="enable_rule",
        op_kwargs={"Name": name, "EventBusName": event_bus_name},
    )


async def list_all(
    hub,
    ctx,
    name_prefix: str = None,
    event_bus_name: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your Amazon EventBridge rules. You can either list all the rules or you can provide a prefix to match to the rule names. ListRules does not list the targets of a rule. To see the targets associated with a rule, use ListTargetsByRule.

    Args:
        name_prefix(str, optional): The prefix matching the rule name. Defaults to None.
        event_bus_name(str, optional): The name or ARN of the event bus to list the rules for. If you omit this, the default event bus is used. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_rules",
        op_kwargs={
            "NamePrefix": name_prefix,
            "EventBusName": event_bus_name,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def put(
    hub,
    ctx,
    name: str,
    schedule_expression: str = None,
    event_pattern: str = None,
    state: str = None,
    description: str = None,
    role_arn: str = None,
    tags: List = None,
    event_bus_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the specified rule. Rules are enabled by default, or based on value of the state. You can disable a rule using DisableRule. A single rule watches for events from a single event bus. Events generated by AWS services go to your account's default event bus. Events generated by SaaS partner services or applications go to the matching partner event bus. If you have custom applications or services, you can specify whether their events go to your default event bus or a custom event bus that you have created. For more information, see CreateEventBus. If you are updating an existing rule, the rule is replaced with what you specify in this PutRule command. If you omit arguments in PutRule, the old values for those arguments are not kept. Instead, they are replaced with null values. When you create or update a rule, incoming events might not immediately start matching to new or updated rules. Allow a short period of time for changes to take effect. A rule must contain at least an EventPattern or ScheduleExpression. Rules with EventPatterns are triggered when a matching event is observed. Rules with ScheduleExpressions self-trigger based on the given schedule. A rule can have both an EventPattern and a ScheduleExpression, in which case the rule triggers on matching events as well as on a schedule. When you initially create a rule, you can optionally assign one or more tags to the rule. Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only rules with certain tag values. To use the PutRule operation and assign tags, you must have both the events:PutRule and events:TagResource permissions. If you are updating an existing rule, any tags you specify in the PutRule operation are ignored. To update the tags of an existing rule, use TagResource and UntagResource. Most services in AWS treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match. In EventBridge, it is possible to create rules that lead to infinite loops, where a rule is fired repeatedly. For example, a rule might detect that ACLs have changed on an S3 bucket, and trigger software to change them to the desired state. If the rule is not written carefully, the subsequent change to the ACLs fires the rule again, creating an infinite loop. To prevent this, write the rules so that the triggered actions do not re-fire the same rule. For example, your rule could fire only if ACLs are found to be in a bad state, instead of after any change.  An infinite loop can quickly cause higher than expected charges. We recommend that you use budgeting, which alerts you when charges exceed your specified limit. For more information, see Managing Your Costs with Budgets.

    Args:
        name(str): The name of the rule that you are creating or updating.
        schedule_expression(str, optional): The scheduling expression. For example, "cron(0 20 * * ? *)" or "rate(5 minutes)". Defaults to None.
        event_pattern(str, optional): The event pattern. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide. Defaults to None.
        state(str, optional): Indicates whether the rule is enabled or disabled. Defaults to None.
        description(str, optional): A description of the rule. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role associated with the rule. Defaults to None.
        tags(List, optional): The list of key-value pairs to associate with the rule. Defaults to None.
        event_bus_name(str, optional): The name or ARN of the event bus to associate with this rule. If you omit this, the default event bus is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.rule.init.put(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.rule.init.put name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="put_rule",
        op_kwargs={
            "Name": name,
            "ScheduleExpression": schedule_expression,
            "EventPattern": event_pattern,
            "State": state,
            "Description": description,
            "RoleArn": role_arn,
            "Tags": tags,
            "EventBusName": event_bus_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified identity (an email address or a domain) from the list of verified identities. You can execute this operation no more than once per second.

    Args:
        identity(str): The identity to be removed from the list of identities for the AWS Account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.init.delete(ctx, identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.init.delete identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_identity",
        op_kwargs={"Identity": identity},
    )


async def list_all(
    hub, ctx, identity_type: str = None, next_token: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list containing all of the identities (email addresses and domains) for your AWS account in the current AWS Region, regardless of verification status. You can execute this operation no more than once per second.

    Args:
        identity_type(str, optional): The type of the identities to list. Possible values are "EmailAddress" and "Domain". If this parameter is omitted, then all identities will be listed. Defaults to None.
        next_token(str, optional): The token to use for pagination. Defaults to None.
        max_items(int, optional): The maximum number of identities per page. Possible values are 1-1000 inclusive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="list_identities",
        op_kwargs={
            "IdentityType": identity_type,
            "NextToken": next_token,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(
    hub, ctx, bucket: str, expected_bucket_owner: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the cors configuration information set for the bucket. To use this operation, you must have permission to perform the s3:PutBucketCORS action. The bucket owner has this permission by default and can grant this permission to others.  For information about cors, see Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.  Related Resources:     PutBucketCors     RESTOPTIONSobject

    Args:
        bucket(str): Specifies the bucket whose cors configuration is being deleted.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.cor.delete_multiple(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.cor.delete_multiple bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_cors",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get_all(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the cors configuration information set for the bucket.  To use this operation, you must have permission to perform the s3:GetBucketCORS action. By default, the bucket owner has this permission and can grant it to others.  For more information about cors, see  Enabling Cross-Origin Resource Sharing. The following operations are related to GetBucketCors:    PutBucketCors     DeleteBucketCors

    Args:
        bucket(str): The bucket name for which to get the cors configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.cor.get_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.cor.get_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_cors",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put_multiple(
    hub,
    ctx,
    bucket: str,
    cors_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the cors configuration for your bucket. If the configuration exists, Amazon S3 replaces it. To use this operation, you must be allowed to perform the s3:PutBucketCORS action. By default, the bucket owner has this permission and can grant it to others. You set this configuration on a bucket so that the bucket can service cross-origin requests. For example, you might want to enable a request whose origin is http://www.example.com to access your Amazon S3 bucket at my.example.bucket.com by using the browser's XMLHttpRequest capability. To enable cross-origin resource sharing (CORS) on a bucket, you add the cors subresource to the bucket. The cors subresource is an XML document in which you configure rules that identify origins and the HTTP methods that can be executed on your bucket. The document is limited to 64 KB in size.  When Amazon S3 receives a cross-origin request (or a pre-flight OPTIONS request) against a bucket, it evaluates the cors configuration on the bucket and uses the first CORSRule rule that matches the incoming browser request to enable a cross-origin request. For a rule to match, the following conditions must be met:   The request's Origin header must match AllowedOrigin elements.   The request method (for example, GET, PUT, HEAD, and so on) or the Access-Control-Request-Method header in case of a pre-flight OPTIONS request must be one of the AllowedMethod elements.    Every header specified in the Access-Control-Request-Headers request header of a pre-flight request must match an AllowedHeader element.     For more information about CORS, go to Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.  Related Resources     GetBucketCors     DeleteBucketCors     RESTOPTIONSobject

    Args:
        bucket(str): Specifies the bucket impacted by the corsconfiguration.
        cors_configuration(Dict): Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.cor.put_multiple(
                ctx, bucket=value, cors_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.cor.put_multiple bucket=value, cors_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_cors",
        op_kwargs={
            "Bucket": bucket,
            "CORSConfiguration": cors_configuration,
            "ContentMD5": content_md5,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, contact_arn: str, address_book_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a contact from a given address book.

    Args:
        contact_arn(str): The ARN of the contact to disassociate from an address book.
        address_book_arn(str): The ARN of the address from which to disassociate the contact.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.contact.from_address_book.disassociate(
                ctx, contact_arn=value, address_book_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.contact.from_address_book.disassociate contact_arn=value, address_book_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="disassociate_contact_from_address_book",
        op_kwargs={"ContactArn": contact_arn, "AddressBookArn": address_book_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def validate(
    hub,
    ctx,
    policy_document: str,
    policy_type: str,
    locale: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Requests the validation of a policy and returns a list of findings. The findings help you identify issues and provide actionable recommendations to resolve the issue and enable you to author functional policies that meet security best practices.

    Args:
        locale(str, optional): The locale to use for localizing the findings. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.
        policy_document(str): The JSON policy document to use as the content for the policy.
        policy_type(str): The type of policy to validate. Identity policies grant permissions to IAM principals. Identity policies include managed and inline policies for IAM roles, users, and groups. They also include service-control policies (SCPs) that are attached to an AWS organization, organizational unit (OU), or an account. Resource policies grant permissions on AWS resources. Resource policies include trust policies for IAM roles and bucket policies for S3 buckets. You can provide a generic input such as identity policy or resource policy or a specific input such as managed policy or S3 bucket policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.policy.init.validate(
                ctx, policy_document=value, policy_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.policy.init.validate policy_document=value, policy_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="validate_policy",
        op_kwargs={
            "locale": locale,
            "maxResults": max_results,
            "nextToken": next_token,
            "policyDocument": policy_document,
            "policyType": policy_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

     Deletes the replication configuration from the bucket. To use this operation, you must have permissions to perform the s3:PutReplicationConfiguration action. The bucket owner has these permissions by default and can grant it to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.   It can take a while for the deletion of a replication configuration to fully propagate.   For information about replication configuration, see Replication in the Amazon S3 User Guide. The following operations are related to DeleteBucketReplication:    PutBucketReplication     GetBucketReplication

    Args:
        bucket(str):  The bucket name. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.replication.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.replication.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_replication",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the replication configuration of a bucket.   It can take a while to propagate the put or delete a replication configuration to all Amazon S3 systems. Therefore, a get request soon after put or delete can return a wrong result.    For information about replication configuration, see Replication in the Amazon S3 User Guide. This action requires permissions for the s3:GetReplicationConfiguration action. For more information about permissions, see Using Bucket Policies and User Policies. If you include the Filter element in a replication configuration, you must also include the DeleteMarkerReplication and Priority elements. The response also returns those elements. For information about GetBucketReplication errors, see List of replication-related error codes  The following operations are related to GetBucketReplication:    PutBucketReplication     DeleteBucketReplication

    Args:
        bucket(str): The bucket name for which to get the replication information.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.replication.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.replication.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_replication",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    replication_configuration: Dict,
    content_md5: str = None,
    token: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

     Creates a replication configuration or replaces an existing one. For more information, see Replication in the Amazon S3 User Guide.   To perform this operation, the user or role performing the action must have the iam:PassRole permission.  Specify the replication configuration in the request body. In the replication configuration, you provide the name of the destination bucket or buckets where you want Amazon S3 to replicate objects, the IAM role that Amazon S3 can assume to replicate objects on your behalf, and other relevant information. A replication configuration must include at least one rule, and can contain a maximum of 1,000. Each rule identifies a subset of objects to replicate by filtering the objects in the source bucket. To choose additional subsets of objects to replicate, add a rule for each subset. To specify a subset of the objects in the source bucket to apply a replication rule to, add the Filter element as a child of the Rule element. You can filter objects based on an object key prefix, one or more object tags, or both. When you add the Filter element in the configuration, you must also add the following elements: DeleteMarkerReplication, Status, and Priority.  If you are using an earlier version of the replication configuration, Amazon S3 handles replication of delete markers differently. For more information, see Backward Compatibility.  For information about enabling versioning on a bucket, see Using Versioning. By default, a resource owner, in this case the AWS account that created the bucket, can perform this operation. The resource owner can also grant others permissions to perform the operation. For more information about permissions, see Specifying Permissions in a Policy and Managing Access Permissions to Your Amazon S3 Resources.  Handling Replication of Encrypted Objects  By default, Amazon S3 doesn't replicate objects that are stored at rest using server-side encryption with CMKs stored in AWS KMS. To replicate AWS KMS-encrypted objects, add the following: SourceSelectionCriteria, SseKmsEncryptedObjects, Status, EncryptionConfiguration, and ReplicaKmsKeyID. For information about replication configuration, see Replicating Objects Created with SSE Using CMKs stored in AWS KMS. For information on PutBucketReplication errors, see List of replication-related error codes  The following operations are related to PutBucketReplication:    GetBucketReplication     DeleteBucketReplication

    Args:
        bucket(str): The name of the bucket.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        replication_configuration(Dict): A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB.
        token(str, optional): A token to allow Object Lock to be enabled for an existing bucket. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.replication.put(
                ctx, bucket=value, replication_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.replication.put bucket=value, replication_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_replication",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "ReplicationConfiguration": replication_configuration,
            "Token": token,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, export_task_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an export task in progress that is exporting a snapshot to Amazon S3. Any data that has already been written to the S3 bucket isn't removed.

    Args:
        export_task_identifier(str): The identifier of the snapshot export task to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.export_task.cancel(ctx, export_task_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.export_task.cancel export_task_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="cancel_export_task",
        op_kwargs={"ExportTaskIdentifier": export_task_identifier},
    )


async def describe_all(
    hub,
    ctx,
    export_task_identifier: str = None,
    source_arn: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a snapshot export to Amazon S3. This API operation supports pagination.

    Args:
        export_task_identifier(str, optional): The identifier of the snapshot export task to be described. Defaults to None.
        source_arn(str, optional): The Amazon Resource Name (ARN) of the snapshot exported to Amazon S3. Defaults to None.
        filters(List, optional): Filters specify one or more snapshot exports to describe. The filters are specified as name-value pairs that define what to include in the output. Filter names and values are case-sensitive. Supported filters include the following:     export-task-identifier - An identifier for the snapshot export task.    s3-bucket - The Amazon S3 bucket the snapshot is exported to.    source-arn - The Amazon Resource Name (ARN) of the snapshot exported to Amazon S3    status - The status of the export task. Must be lowercase, for example, complete.  . Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeExportTasks request. If you specify this parameter, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter. . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified value, a pagination token called a marker is included in the response. You can use the marker in a later DescribeExportTasks request to retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.export_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.export_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_export_tasks",
        op_kwargs={
            "ExportTaskIdentifier": export_task_identifier,
            "SourceArn": source_arn,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def start(
    hub,
    ctx,
    export_task_identifier: str,
    source_arn: str,
    s3_bucket_name: str,
    iam_role_arn: str,
    kms_key_id: str,
    s3_prefix: str = None,
    export_only: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an export of a snapshot to Amazon S3. The provided IAM role must have access to the S3 bucket.

    Args:
        export_task_identifier(str): A unique identifier for the snapshot export task. This ID isn't an identifier for the Amazon S3 bucket where the snapshot is to be exported to. .
        source_arn(str): The Amazon Resource Name (ARN) of the snapshot to export to Amazon S3.
        s3_bucket_name(str): The name of the Amazon S3 bucket to export the snapshot to.
        iam_role_arn(str): The name of the IAM role to use for writing to the Amazon S3 bucket when exporting a snapshot. .
        kms_key_id(str): The ID of the Amazon Web Services KMS customer master key (CMK) to use to encrypt the snapshot exported to Amazon S3. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). The caller of this operation must be authorized to execute the following operations. These can be set in the Amazon Web Services KMS key policy:    GrantOperation.Encrypt   GrantOperation.Decrypt   GrantOperation.GenerateDataKey   GrantOperation.GenerateDataKeyWithoutPlaintext   GrantOperation.ReEncryptFrom   GrantOperation.ReEncryptTo   GrantOperation.CreateGrant   GrantOperation.DescribeKey   GrantOperation.RetireGrant  .
        s3_prefix(str, optional): The Amazon S3 bucket prefix to use as the file name and path of the exported snapshot. Defaults to None.
        export_only(List, optional): The data to be exported from the snapshot. If this parameter is not provided, all the snapshot data is exported. Valid values are the following:    database - Export all the data from a specified database.    database.table table-name - Export a table of the snapshot. This format is valid only for RDS for MySQL, RDS for MariaDB, and Aurora MySQL.    database.schema schema-name - Export a database schema of the snapshot. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.    database.schema.table table-name - Export a table of the database schema. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.export_task.start(
                ctx,
                export_task_identifier=value,
                source_arn=value,
                s3_bucket_name=value,
                iam_role_arn=value,
                kms_key_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.export_task.start export_task_identifier=value, source_arn=value, s3_bucket_name=value, iam_role_arn=value, kms_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="start_export_task",
        op_kwargs={
            "ExportTaskIdentifier": export_task_identifier,
            "SourceArn": source_arn,
            "S3BucketName": s3_bucket_name,
            "IamRoleArn": iam_role_arn,
            "KmsKeyId": kms_key_id,
            "S3Prefix": s3_prefix,
            "ExportOnly": export_only,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, domain: str, user_pool_id: str, custom_domain_config: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new domain for a user pool.

    Args:
        domain(str): The domain string.
        user_pool_id(str): The user pool ID.
        custom_domain_config(Dict, optional): The configuration for a custom domain that hosts the sign-up and sign-in webpages for your application. Provide this parameter only if you want to use a custom domain for your user pool. Otherwise, you can exclude this parameter and use the Amazon Cognito hosted domain instead. For more information about the hosted domain and custom domains, see Configuring a User Pool Domain. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.domain.create(
                ctx, domain=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.domain.create domain=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_user_pool_domain",
        op_kwargs={
            "Domain": domain,
            "UserPoolId": user_pool_id,
            "CustomDomainConfig": custom_domain_config,
        },
    )


async def delete(hub, ctx, domain: str, user_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a domain for a user pool.

    Args:
        domain(str): The domain string.
        user_pool_id(str): The user pool ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.domain.delete(
                ctx, domain=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.domain.delete domain=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_user_pool_domain",
        op_kwargs={"Domain": domain, "UserPoolId": user_pool_id},
    )


async def describe(hub, ctx, domain: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a domain.

    Args:
        domain(str): The domain string.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.domain.describe(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.domain.describe domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_user_pool_domain",
        op_kwargs={"Domain": domain},
    )


async def update(
    hub, ctx, domain: str, user_pool_id: str, custom_domain_config: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Secure Sockets Layer (SSL) certificate for the custom domain for your user pool. You can use this operation to provide the Amazon Resource Name (ARN) of a new certificate to Amazon Cognito. You cannot use it to change the domain for a user pool. A custom domain is used to host the Amazon Cognito hosted UI, which provides sign-up and sign-in pages for your application. When you set up a custom domain, you provide a certificate that you manage with Certificate Manager (ACM). When necessary, you can use this operation to change the certificate that you applied to your custom domain. Usually, this is unnecessary following routine certificate renewal with ACM. When you renew your existing certificate in ACM, the ARN for your certificate remains the same, and your custom domain uses the new certificate automatically. However, if you replace your existing certificate with a new one, ACM gives the new certificate a new ARN. To apply the new certificate to your custom domain, you must provide this ARN to Amazon Cognito. When you add your new certificate in ACM, you must choose US East (N. Virginia) as the Region. After you submit your request, Amazon Cognito requires up to 1 hour to distribute your new certificate to your custom domain. For more information about adding a custom domain to your user pool, see Using Your Own Domain for the Hosted UI.

    Args:
        domain(str): The domain name for the custom domain that hosts the sign-up and sign-in pages for your application. For example: auth.example.com.  This string can include only lowercase letters, numbers, and hyphens. Do not use a hyphen for the first or last character. Use periods to separate subdomain names.
        user_pool_id(str): The ID of the user pool that is associated with the custom domain that you are updating the certificate for.
        custom_domain_config(Dict): The configuration for a custom domain that hosts the sign-up and sign-in pages for your application. Use this object to specify an SSL certificate that is managed by ACM.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.domain.update(
                ctx, domain=value, user_pool_id=value, custom_domain_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.domain.update domain=value, user_pool_id=value, custom_domain_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_user_pool_domain",
        op_kwargs={
            "Domain": domain,
            "UserPoolId": user_pool_id,
            "CustomDomainConfig": custom_domain_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, account_id: str, vault_name: str, job_id: str, range_: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation downloads the output of the job you initiated using InitiateJob. Depending on the job type you specified when you initiated the job, the output will be either the content of an archive or a vault inventory. You can download all the job output or download a portion of the output by specifying a byte range. In the case of an archive retrieval job, depending on the byte range you specify, Amazon S3 Glacier (Glacier) returns the checksum for the portion of the data. You can compute the checksum on the client and verify that the values match to ensure the portion you downloaded is the correct data. A job ID will not expire for at least 24 hours after Glacier completes the job. That a byte range. For both archive and inventory retrieval jobs, you should verify the downloaded size against the size returned in the headers from the Get Job Output response. For archive retrieval jobs, you should also verify that the size is what you expected. If you download a portion of the output, the expected size is based on the range of bytes you specified. For example, if you specify a range of bytes=0-1048575, you should verify your download size is 1,048,576 bytes. If you download an entire archive, the expected size is the size of the archive when you uploaded it to Amazon S3 Glacier The expected size is also returned in the headers from the Get Job Output response. In the case of an archive retrieval job, depending on the byte range you specify, Glacier returns the checksum for the portion of the data. To ensure the portion you downloaded is the correct data, compute the checksum on the client, verify that the values match, and verify that the size is what you expected. A job ID does not expire for at least 24 hours after Glacier completes the job. That is, you can download the job output within the 24 hours period after Amazon Glacier completes the job. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and the underlying REST API, see Downloading a Vault Inventory, Downloading an Archive, and Get Job Output

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        job_id(str): The job ID whose data is downloaded.
        range_(str, optional): The range of bytes to retrieve from the output. For example, if you want to download the first 1,048,576 bytes, specify the range as bytes=0-1048575. By default, this operation downloads the entire output. If the job output is large, then you can use a range to retrieve a portion of the output. This allows you to download the entire output in smaller chunks of bytes. For example, suppose you have 1 GB of job output you want to download and you decide to download 128 MB chunks of data at a time, which is a total of eight Get Job Output requests. You use the following process to download the job output:   Download a 128 MB chunk of output by specifying the appropriate byte range. Verify that all 128 MB of data was received.   Along with the data, the response includes a SHA256 tree hash of the payload. You compute the checksum of the payload on the client and compare it with the checksum you received in the response to ensure you received all the expected data.   Repeat steps 1 and 2 for all the eight 128 MB chunks of output data, each time specifying the appropriate byte range.   After downloading all the parts of the job output, you have a list of eight checksum values. Compute the tree hash of these values to find the checksum of the entire output. Using the DescribeJob API, obtain job information of the job that provided you the output. The response includes the checksum of the entire archive stored in Amazon S3 Glacier. You compare this value with the checksum you computed to ensure you have downloaded the entire archive content with no errors.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.job.output.get(
                ctx, account_id=value, vault_name=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.job.output.get account_id=value, vault_name=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="get_job_output",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "jobId": job_id,
            "range": range_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"filter_": "filter"}


async def filter_(
    hub,
    ctx,
    log_group_name: str,
    log_stream_names: List = None,
    log_stream_name_prefix: str = None,
    start_time: int = None,
    end_time: int = None,
    filter_pattern: str = None,
    next_token: str = None,
    limit: int = None,
    interleaved: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists log events from the specified log group. You can list all the log events or filter the results using a filter pattern, a time range, and the name of the log stream. By default, this operation returns as many log events as can fit in 1 MB (up to 10,000 log events) or all the events found within the time range that you specify. If the results include a token, then there are more log events available, and you can get additional results by specifying the token in a subsequent call. This operation can return empty results while there are more log events available through the token. The returned log events are sorted by event timestamp, the timestamp when the event was ingested by CloudWatch Logs, and the ID of the PutLogEvents request.

    Args:
        log_group_name(str): The name of the log group to search.
        log_stream_names(List, optional): Filters the results to only logs from the log streams in this list. If you specify a value for both logStreamNamePrefix and logStreamNames, the action returns an InvalidParameterException error. Defaults to None.
        log_stream_name_prefix(str, optional): Filters the results to include only events from log streams that have names starting with this prefix. If you specify a value for both logStreamNamePrefix and logStreamNames, but the value for logStreamNamePrefix does not match any log stream names specified in logStreamNames, the action returns an InvalidParameterException error. Defaults to None.
        start_time(int, optional): The start of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp before this time are not returned. Defaults to None.
        end_time(int, optional): The end of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp later than this time are not returned. Defaults to None.
        filter_pattern(str, optional): The filter pattern to use. For more information, see Filter and Pattern Syntax. If not provided, all the events are matched. Defaults to None.
        next_token(str, optional): The token for the next set of events to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of events to return. The default is 10,000 events. Defaults to None.
        interleaved(bool, optional): If the value is true, the operation makes a best effort to provide responses that contain events from multiple log streams within the log group, interleaved in a single response. If the value is false, all the matched log events in the first log stream are searched first, then those in the next log stream, and so on. The default is false.  Important: Starting on June 17, 2019, this parameter is ignored and the value is assumed to be true. The response from this operation always interleaves events from multiple log streams within a log group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.event.filter(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.event.filter log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="filter_log_events",
        op_kwargs={
            "logGroupName": log_group_name,
            "logStreamNames": log_stream_names,
            "logStreamNamePrefix": log_stream_name_prefix,
            "startTime": start_time,
            "endTime": end_time,
            "filterPattern": filter_pattern,
            "nextToken": next_token,
            "limit": limit,
            "interleaved": interleaved,
        },
    )


async def get_all(
    hub,
    ctx,
    log_group_name: str,
    log_stream_name: str,
    start_time: int = None,
    end_time: int = None,
    next_token: str = None,
    limit: int = None,
    start_from_head: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists log events from the specified log stream. You can list all of the log events or filter using a time range. By default, this operation returns as many log events as can fit in a response size of 1MB (up to 10,000 log events). You can get additional log events by specifying one of the tokens in a subsequent call. This operation can return empty results while there are more log events available through the token.

    Args:
        log_group_name(str): The name of the log group.
        log_stream_name(str): The name of the log stream.
        start_time(int, optional): The start of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to this time or later than this time are included. Events with a timestamp earlier than this time are not included. Defaults to None.
        end_time(int, optional): The end of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to or later than this time are not included. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.) Using this token works only when you specify true for startFromHead. Defaults to None.
        limit(int, optional): The maximum number of log events returned. If you don't specify a value, the maximum is as many log events as can fit in a response size of 1 MB, up to 10,000 log events. Defaults to None.
        start_from_head(bool, optional): If the value is true, the earliest log events are returned first. If the value is false, the latest log events are returned first. The default value is false. If you are using nextToken in this operation, you must specify true for startFromHead. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.event.get_all(
                ctx, log_group_name=value, log_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.event.get_all log_group_name=value, log_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="get_log_events",
        op_kwargs={
            "logGroupName": log_group_name,
            "logStreamName": log_stream_name,
            "startTime": start_time,
            "endTime": end_time,
            "nextToken": next_token,
            "limit": limit,
            "startFromHead": start_from_head,
        },
    )


async def put_multiple(
    hub,
    ctx,
    log_group_name: str,
    log_stream_name: str,
    log_events: List,
    sequence_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a batch of log events to the specified log stream. You must include the sequence token obtained from the response of the previous call. An upload in a newly created log stream does not require a sequence token. You can also get the sequence token in the expectedSequenceToken field from InvalidSequenceTokenException. If you call PutLogEvents twice within a narrow time period using the same value for sequenceToken, both calls might be successful or one might be rejected. The batch of events must satisfy the following constraints:   The maximum batch size is 1,048,576 bytes. This size is calculated as the sum of all event messages in UTF-8, plus 26 bytes for each log event.   None of the log events in the batch can be more than 2 hours in the future.   None of the log events in the batch can be older than 14 days or older than the retention period of the log group.   The log events in the batch must be in chronological order by their timestamp. The timestamp is the time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. (In AWS Tools for PowerShell and the AWS SDK for .NET, the timestamp is specified in .NET format: yyyy-mm-ddThh:mm:ss. For example, 2017-09-15T13:45:30.)    A batch of log events in a single request cannot span more than 24 hours. Otherwise, the operation fails.   The maximum number of log events in a batch is 10,000.   There is a quota of 5 requests per second per log stream. Additional requests are throttled. This quota can't be changed.   If a call to PutLogEvents returns "UnrecognizedClientException" the most likely cause is an invalid AWS access key ID or secret key.

    Args:
        log_group_name(str): The name of the log group.
        log_stream_name(str): The name of the log stream.
        log_events(List): The log events.
        sequence_token(str, optional): The sequence token obtained from the response of the previous PutLogEvents call. An upload in a newly created log stream does not require a sequence token. You can also get the sequence token using DescribeLogStreams. If you call PutLogEvents twice within a narrow time period using the same value for sequenceToken, both calls might be successful or one might be rejected. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.event.put_multiple(
                ctx, log_group_name=value, log_stream_name=value, log_events=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.event.put_multiple log_group_name=value, log_stream_name=value, log_events=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_log_events",
        op_kwargs={
            "logGroupName": log_group_name,
            "logStreamName": log_stream_name,
            "logEvents": log_events,
            "sequenceToken": sequence_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, instance_name: str, protocol: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns temporary SSH keys you can use to connect to a specific virtual private server, or instance. The get instance access details operation supports tag-based access control via resource tags applied to the resource identified by instance name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_name(str): The name of the instance to access.
        protocol(str, optional): The protocol to use to connect to your instance. Defaults to ssh. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.access_detail.get_all(
                ctx, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.access_detail.get_all instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance_access_details",
        op_kwargs={"instanceName": instance_name, "protocol": protocol},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def describe(hub, ctx, create_account_request_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current status of an asynchronous request to create an account. This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        create_account_request_id(str): Specifies the Id value that uniquely identifies the CreateAccount request. You can get the value from the CreateAccountStatus.Id response in an earlier CreateAccount request, or from the ListCreateAccountStatus operation. The regex pattern for a create account request ID string requires "car-" followed by from 8 to 32 lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.create_account_status.describe(
                ctx, create_account_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.create_account_status.describe create_account_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_create_account_status",
        op_kwargs={"CreateAccountRequestId": create_account_request_id},
    )


async def list_(
    hub, ctx, states: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the account creation requests that match the specified status that is currently being tracked for the organization.  Always check the NextToken response parameter for a null value when calling a List* operation. These operations can occasionally return an empty set of results even when there are more results available. The NextToken response parameter value is null only when there are no more results to display.  This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        states(List, optional): A list of one or more states that you want included in the response. If this parameter isn't present, all requests are included in the response. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Organizations might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.create_account_status.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.create_account_status.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_create_account_status",
        op_kwargs={
            "States": states,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    project_arn: str,
    name: str,
    description: str = None,
    type_: str = None,
    uplink_bandwidth_bits: int = None,
    downlink_bandwidth_bits: int = None,
    uplink_delay_ms: int = None,
    downlink_delay_ms: int = None,
    uplink_jitter_ms: int = None,
    downlink_jitter_ms: int = None,
    uplink_loss_percent: int = None,
    downlink_loss_percent: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a network profile.

    Args:
        project_arn(str): The Amazon Resource Name (ARN) of the project for which you want to create a network profile.
        name(str): The name for the new network profile.
        description(str, optional): The description of the network profile. Defaults to None.
        type_(str, optional): The type of network profile to create. Valid values are listed here. Defaults to None.
        uplink_bandwidth_bits(int, optional): The data throughput rate in bits per second, as an integer from 0 to 104857600. Defaults to None.
        downlink_bandwidth_bits(int, optional): The data throughput rate in bits per second, as an integer from 0 to 104857600. Defaults to None.
        uplink_delay_ms(int, optional): Delay time for all packets to destination in milliseconds as an integer from 0 to 2000. Defaults to None.
        downlink_delay_ms(int, optional): Delay time for all packets to destination in milliseconds as an integer from 0 to 2000. Defaults to None.
        uplink_jitter_ms(int, optional): Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000. Defaults to None.
        downlink_jitter_ms(int, optional): Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000. Defaults to None.
        uplink_loss_percent(int, optional): Proportion of transmitted packets that fail to arrive from 0 to 100 percent. Defaults to None.
        downlink_loss_percent(int, optional): Proportion of received packets that fail to arrive from 0 to 100 percent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.network_profile.create(
                ctx, project_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.network_profile.create project_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_network_profile",
        op_kwargs={
            "projectArn": project_arn,
            "name": name,
            "description": description,
            "type": type_,
            "uplinkBandwidthBits": uplink_bandwidth_bits,
            "downlinkBandwidthBits": downlink_bandwidth_bits,
            "uplinkDelayMs": uplink_delay_ms,
            "downlinkDelayMs": downlink_delay_ms,
            "uplinkJitterMs": uplink_jitter_ms,
            "downlinkJitterMs": downlink_jitter_ms,
            "uplinkLossPercent": uplink_loss_percent,
            "downlinkLossPercent": downlink_loss_percent,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a network profile.

    Args:
        arn(str): The ARN of the network profile to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.network_profile.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.network_profile.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_network_profile",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a network profile.

    Args:
        arn(str): The ARN of the network profile to return information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.network_profile.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.network_profile.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_network_profile",
        op_kwargs={"arn": arn},
    )


async def list_all(
    hub, ctx, arn: str, type_: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of available network profiles.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the project for which you want to list network profiles.
        type_(str, optional): The type of network profile to return information about. Valid values are listed here. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.network_profile.list_all(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.network_profile.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_network_profiles",
        op_kwargs={"arn": arn, "type": type_, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    description: str = None,
    type_: str = None,
    uplink_bandwidth_bits: int = None,
    downlink_bandwidth_bits: int = None,
    uplink_delay_ms: int = None,
    downlink_delay_ms: int = None,
    uplink_jitter_ms: int = None,
    downlink_jitter_ms: int = None,
    uplink_loss_percent: int = None,
    downlink_loss_percent: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the network profile.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the project for which you want to update network profile settings.
        name(str, optional): The name of the network profile about which you are returning information. Defaults to None.
        description(str, optional): The description of the network profile about which you are returning information. Defaults to None.
        type_(str, optional): The type of network profile to return information about. Valid values are listed here. Defaults to None.
        uplink_bandwidth_bits(int, optional): The data throughput rate in bits per second, as an integer from 0 to 104857600. Defaults to None.
        downlink_bandwidth_bits(int, optional): The data throughput rate in bits per second, as an integer from 0 to 104857600. Defaults to None.
        uplink_delay_ms(int, optional): Delay time for all packets to destination in milliseconds as an integer from 0 to 2000. Defaults to None.
        downlink_delay_ms(int, optional): Delay time for all packets to destination in milliseconds as an integer from 0 to 2000. Defaults to None.
        uplink_jitter_ms(int, optional): Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000. Defaults to None.
        downlink_jitter_ms(int, optional): Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000. Defaults to None.
        uplink_loss_percent(int, optional): Proportion of transmitted packets that fail to arrive from 0 to 100 percent. Defaults to None.
        downlink_loss_percent(int, optional): Proportion of received packets that fail to arrive from 0 to 100 percent. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.network_profile.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.network_profile.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_network_profile",
        op_kwargs={
            "arn": arn,
            "name": name,
            "description": description,
            "type": type_,
            "uplinkBandwidthBits": uplink_bandwidth_bits,
            "downlinkBandwidthBits": downlink_bandwidth_bits,
            "uplinkDelayMs": uplink_delay_ms,
            "downlinkDelayMs": downlink_delay_ms,
            "uplinkJitterMs": uplink_jitter_ms,
            "downlinkJitterMs": downlink_jitter_ms,
            "uplinkLossPercent": uplink_loss_percent,
            "downlinkLossPercent": downlink_loss_percent,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, repository_name: str, folder_path: str, commit_specifier: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the contents of a specified folder in a repository.

    Args:
        repository_name(str): The name of the repository.
        commit_specifier(str, optional): A fully qualified reference used to identify a commit that contains the version of the folder's content to return. A fully qualified reference can be a commit ID, branch name, tag, or reference such as HEAD. If no specifier is provided, the folder content is returned as it exists in the HEAD commit. Defaults to None.
        folder_path(str): The fully qualified path to the folder whose contents are returned, including the folder name. For example, /examples is a fully-qualified path to a folder named examples that was created off of the root directory (/) of a repository. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.folder.get(
                ctx, repository_name=value, folder_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.folder.get repository_name=value, folder_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_folder",
        op_kwargs={
            "repositoryName": repository_name,
            "commitSpecifier": commit_specifier,
            "folderPath": folder_path,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    game_server_group_name: str,
    role_arn: str,
    min_size: int,
    max_size: int,
    launch_template: Dict,
    instance_definitions: List,
    auto_scaling_policy: Dict = None,
    balancing_strategy: str = None,
    game_server_protection_policy: str = None,
    vpc_subnets: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Creates a GameLift FleetIQ game server group for managing game hosting on a collection of Amazon EC2 instances for game hosting. This operation creates the game server group, creates an Auto Scaling group in your AWS account, and establishes a link between the two groups. You can view the status of your game server groups in the GameLift console. Game server group metrics and events are emitted to Amazon CloudWatch. Before creating a new game server group, you must have the following:    An Amazon EC2 launch template that specifies how to launch Amazon EC2 instances with your game server build. For more information, see  Launching an Instance from a Launch Template in the Amazon EC2 User Guide.    An IAM role that extends limited access to your AWS account to allow GameLift FleetIQ to create and interact with the Auto Scaling group. For more information, see Create IAM roles for cross-service interaction in the GameLift FleetIQ Developer Guide.   To create a new game server group, specify a unique group name, IAM role and Amazon EC2 launch template, and provide a list of instance types that can be used in the group. You must also set initial maximum and minimum limits on the group's instance count. You can optionally set an Auto Scaling policy with target tracking based on a GameLift FleetIQ metric. Once the game server group and corresponding Auto Scaling group are created, you have full access to change the Auto Scaling group's configuration as needed. Several properties that are set when creating a game server group, including maximum/minimum size and auto-scaling policy settings, must be updated directly in the Auto Scaling group. Keep in mind that some Auto Scaling group properties are periodically updated by GameLift FleetIQ as part of its balancing activities to optimize for availability and cost.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): An identifier for the new game server group. This value is used to generate unique ARN identifiers for the EC2 Auto Scaling group and the GameLift FleetIQ game server group. The name must be unique per Region per AWS account.
        role_arn(str): The Amazon Resource Name (ARN) for an IAM role that allows Amazon GameLift to access your EC2 Auto Scaling groups.
        min_size(int): The minimum number of instances allowed in the EC2 Auto Scaling group. During automatic scaling events, GameLift FleetIQ and EC2 do not scale down the group below this minimum. In production, this value should be set to at least 1. After the Auto Scaling group is created, update this value directly in the Auto Scaling group using the AWS console or APIs.
        max_size(int): The maximum number of instances allowed in the EC2 Auto Scaling group. During automatic scaling events, GameLift FleetIQ and EC2 do not scale up the group above this maximum. After the Auto Scaling group is created, update this value directly in the Auto Scaling group using the AWS console or APIs.
        launch_template(Dict): The EC2 launch template that contains configuration settings and game server code to be deployed to all instances in the game server group. You can specify the template using either the template name or ID. For help with creating a launch template, see Creating a Launch Template for an Auto Scaling Group in the Amazon EC2 Auto Scaling User Guide. After the Auto Scaling group is created, update this value directly in the Auto Scaling group using the AWS console or APIs.  If you specify network interfaces in your launch template, you must explicitly set the property AssociatePublicIpAddress to "true". If no network interface is specified in the launch template, GameLift FleetIQ uses your account's default VPC. .
        instance_definitions(List): The EC2 instance types and sizes to use in the Auto Scaling group. The instance definitions must specify at least two different instance types that are supported by GameLift FleetIQ. For more information on instance types, see EC2 Instance Types in the Amazon EC2 User Guide. You can optionally specify capacity weighting for each instance type. If no weight value is specified for an instance type, it is set to the default value "1". For more information about capacity weighting, see  Instance Weighting for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
        auto_scaling_policy(Dict, optional): Configuration settings to define a scaling policy for the Auto Scaling group that is optimized for game hosting. The scaling policy uses the metric "PercentUtilizedGameServers" to maintain a buffer of idle game servers that can immediately accommodate new games and players. After the Auto Scaling group is created, update this value directly in the Auto Scaling group using the AWS console or APIs. Defaults to None.
        balancing_strategy(str, optional): Indicates how GameLift FleetIQ balances the use of Spot Instances and On-Demand Instances in the game server group. Method options include the following:    SPOT_ONLY - Only Spot Instances are used in the game server group. If Spot Instances are unavailable or not viable for game hosting, the game server group provides no hosting capacity until Spot Instances can again be used. Until then, no new instances are started, and the existing nonviable Spot Instances are terminated (after current gameplay ends) and are not replaced.    SPOT_PREFERRED - (default value) Spot Instances are used whenever available in the game server group. If Spot Instances are unavailable, the game server group continues to provide hosting capacity by falling back to On-Demand Instances. Existing nonviable Spot Instances are terminated (after current gameplay ends) and are replaced with new On-Demand Instances.    ON_DEMAND_ONLY - Only On-Demand Instances are used in the game server group. No Spot Instances are used, even when available, while this balancing strategy is in force.  . Defaults to None.
        game_server_protection_policy(str, optional): A flag that indicates whether instances in the game server group are protected from early termination. Unprotected instances that have active game servers running might be terminated during a scale-down event, causing players to be dropped from the game. Protected instances cannot be terminated while there are active game servers running except in the event of a forced game server group deletion (see ). An exception to this is with Spot Instances, which can be terminated by AWS regardless of protection status. This property is set to NO_PROTECTION by default. Defaults to None.
        vpc_subnets(List, optional): A list of virtual private cloud (VPC) subnets to use with instances in the game server group. By default, all GameLift FleetIQ-supported Availability Zones are used. You can use this parameter to specify VPCs that you've set up. This property cannot be updated after the game server group is created, and the corresponding Auto Scaling group will always use the property value that is set with this request, even if the Auto Scaling group is updated directly. Defaults to None.
        tags(List, optional): A list of labels to assign to the new game server group resource. Tags are developer-defined key-value pairs. Tagging AWS resources is useful for resource management, access management, and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags, respectively. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.create(
                ctx,
                game_server_group_name=value,
                role_arn=value,
                min_size=value,
                max_size=value,
                launch_template=value,
                instance_definitions=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.create game_server_group_name=value, role_arn=value, min_size=value, max_size=value, launch_template=value, instance_definitions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_game_server_group",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "RoleArn": role_arn,
            "MinSize": min_size,
            "MaxSize": max_size,
            "LaunchTemplate": launch_template,
            "InstanceDefinitions": instance_definitions,
            "AutoScalingPolicy": auto_scaling_policy,
            "BalancingStrategy": balancing_strategy,
            "GameServerProtectionPolicy": game_server_protection_policy,
            "VpcSubnets": vpc_subnets,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, game_server_group_name: str, delete_option: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Terminates a game server group and permanently deletes the game server group record. You have several options for how these resources are impacted when deleting the game server group. Depending on the type of delete operation selected, this operation might affect these resources:   The game server group   The corresponding Auto Scaling group   All game servers that are currently running in the group   To delete a game server group, identify the game server group to delete and specify the type of delete operation to initiate. Game server groups can only be deleted if they are in ACTIVE or ERROR status. If the delete request is successful, a series of operations are kicked off. The game server group status is changed to DELETE_SCHEDULED, which prevents new game servers from being registered and stops automatic scaling activity. Once all game servers in the game server group are deregistered, GameLift FleetIQ can begin deleting resources. If any of the delete operations fail, the game server group is placed in ERROR status. GameLift FleetIQ emits delete events to Amazon CloudWatch.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.
        delete_option(str, optional): The type of delete to perform. Options include the following:    SAFE_DELETE – (default) Terminates the game server group and EC2 Auto Scaling group only when it has no game servers that are in UTILIZED status.    FORCE_DELETE – Terminates the game server group, including all active game servers regardless of their utilization status, and the EC2 Auto Scaling group.     RETAIN – Does a safe delete of the game server group but retains the EC2 Auto Scaling group as is.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.delete(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.delete game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_game_server_group",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "DeleteOption": delete_option,
        },
    )


async def describe(hub, ctx, game_server_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Retrieves information on a game server group. This operation returns only properties related to GameLift FleetIQ. To view or update properties for the corresponding Auto Scaling group, such as launch template, auto scaling policies, and maximum/minimum group size, access the Auto Scaling group directly. To get attributes for a game server group, provide a group name or ARN value. If successful, a GameServerGroup object is returned.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.describe(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.describe game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_server_group",
        op_kwargs={"GameServerGroupName": game_server_group_name},
    )


async def list_all(hub, ctx, limit: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Retrieves information on all game servers groups that exist in the current AWS account for the selected Region. Use the pagination parameters to retrieve results in a set of sequential segments.   Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_game_server_groups",
        op_kwargs={"Limit": limit, "NextToken": next_token},
    )


async def resume(hub, ctx, game_server_group_name: str, resume_actions: List) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Reinstates activity on a game server group after it has been suspended. A game server group might be suspended by theSuspendGameServerGroup operation, or it might be suspended involuntarily due to a configuration problem. In the second case, you can manually resume activity on the group once the configuration problem has been resolved. Refer to the game server group status and status reason for more information on why group activity is suspended. To resume activity, specify a game server group ARN and the type of activity to be resumed. If successful, a GameServerGroup object is returned showing that the resumed activity is no longer listed in SuspendedActions.   Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.
        resume_actions(List): The activity to resume for this game server group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.resume(
                ctx, game_server_group_name=value, resume_actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.resume game_server_group_name=value, resume_actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="resume_game_server_group",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "ResumeActions": resume_actions,
        },
    )


async def suspend(hub, ctx, game_server_group_name: str, suspend_actions: List) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Temporarily stops activity on a game server group without terminating instances or the game server group. You can restart activity by calling ResumeGameServerGroup. You can suspend the following activity:    Instance type replacement - This activity evaluates the current game hosting viability of all Spot instance types that are defined for the game server group. It updates the Auto Scaling group to remove nonviable Spot Instance types, which have a higher chance of game server interruptions. It then balances capacity across the remaining viable Spot Instance types. When this activity is suspended, the Auto Scaling group continues with its current balance, regardless of viability. Instance protection, utilization metrics, and capacity scaling activities continue to be active.    To suspend activity, specify a game server group ARN and the type of activity to be suspended. If successful, a GameServerGroup object is returned showing that the activity is listed in SuspendedActions.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.
        suspend_actions(List): The activity to suspend for this game server group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.suspend(
                ctx, game_server_group_name=value, suspend_actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.suspend game_server_group_name=value, suspend_actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="suspend_game_server_group",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "SuspendActions": suspend_actions,
        },
    )


async def update(
    hub,
    ctx,
    game_server_group_name: str,
    role_arn: str = None,
    instance_definitions: List = None,
    game_server_protection_policy: str = None,
    balancing_strategy: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Updates GameLift FleetIQ-specific properties for a game server group. Many Auto Scaling group properties are updated on the Auto Scaling group directly, including the launch template, Auto Scaling policies, and maximum/minimum/desired instance counts. To update the game server group, specify the game server group ID and provide the updated values. Before applying the updates, the new values are validated to ensure that GameLift FleetIQ can continue to perform instance balancing activity. If successful, a GameServerGroup object is returned.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.
        role_arn(str, optional): The Amazon Resource Name (ARN) for an IAM role that allows Amazon GameLift to access your EC2 Auto Scaling groups. Defaults to None.
        instance_definitions(List, optional): An updated list of EC2 instance types to use in the Auto Scaling group. The instance definitions must specify at least two different instance types that are supported by GameLift FleetIQ. This updated list replaces the entire current list of instance definitions for the game server group. For more information on instance types, see EC2 Instance Types in the Amazon EC2 User Guide. You can optionally specify capacity weighting for each instance type. If no weight value is specified for an instance type, it is set to the default value "1". For more information about capacity weighting, see  Instance Weighting for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        game_server_protection_policy(str, optional): A flag that indicates whether instances in the game server group are protected from early termination. Unprotected instances that have active game servers running might be terminated during a scale-down event, causing players to be dropped from the game. Protected instances cannot be terminated while there are active game servers running except in the event of a forced game server group deletion (see ). An exception to this is with Spot Instances, which can be terminated by AWS regardless of protection status. This property is set to NO_PROTECTION by default. Defaults to None.
        balancing_strategy(str, optional): Indicates how GameLift FleetIQ balances the use of Spot Instances and On-Demand Instances in the game server group. Method options include the following:    SPOT_ONLY - Only Spot Instances are used in the game server group. If Spot Instances are unavailable or not viable for game hosting, the game server group provides no hosting capacity until Spot Instances can again be used. Until then, no new instances are started, and the existing nonviable Spot Instances are terminated (after current gameplay ends) and are not replaced.    SPOT_PREFERRED - (default value) Spot Instances are used whenever available in the game server group. If Spot Instances are unavailable, the game server group continues to provide hosting capacity by falling back to On-Demand Instances. Existing nonviable Spot Instances are terminated (after current gameplay ends) and are replaced with new On-Demand Instances.    ON_DEMAND_ONLY - Only On-Demand Instances are used in the game server group. No Spot Instances are used, even when available, while this balancing strategy is in force.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.group.update(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.group.update game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_game_server_group",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "RoleArn": role_arn,
            "InstanceDefinitions": instance_definitions,
            "GameServerProtectionPolicy": game_server_protection_policy,
            "BalancingStrategy": balancing_strategy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    product_id: str,
    provisioning_artifact_id: str,
    service_action_id: str,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a self-service action with a provisioning artifact.

    Args:
        product_id(str): The product identifier. For example, prod-abcdzk7xy33qa.
        provisioning_artifact_id(str): The identifier of the provisioning artifact. For example, pa-4abcdjnxjj6ne.
        service_action_id(str): The self-service action identifier. For example, act-fs7abcd89wxyz.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.with_provisioning_artifact.associate(
                ctx, product_id=value, provisioning_artifact_id=value, service_action_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.with_provisioning_artifact.associate product_id=value, provisioning_artifact_id=value, service_action_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="associate_service_action_with_provisioning_artifact",
        op_kwargs={
            "ProductId": product_id,
            "ProvisioningArtifactId": provisioning_artifact_id,
            "ServiceActionId": service_action_id,
            "AcceptLanguage": accept_language,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def apply(
    hub, ctx, resource_identifier: str, apply_action: str, opt_in_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a pending maintenance action to a resource (for example, to a DB instance).

    Args:
        resource_identifier(str): The Amazon Resource Name (ARN) of the resource that the pending maintenance action applies to. For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN).
        apply_action(str): The pending maintenance action to apply to this resource. Valid values: system-update, db-upgrade .
        opt_in_type(str): A value that specifies the type of opt-in request, or undoes an opt-in request. An opt-in request of type immediate can't be undone. Valid values:    immediate - Apply the maintenance action immediately.    next-maintenance - Apply the maintenance action during the next maintenance window for the resource.    undo-opt-in - Cancel any existing next-maintenance opt-in requests.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.pending_maintenance_action.apply(
                ctx, resource_identifier=value, apply_action=value, opt_in_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.pending_maintenance_action.apply resource_identifier=value, apply_action=value, opt_in_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="apply_pending_maintenance_action",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "ApplyAction": apply_action,
            "OptInType": opt_in_type,
        },
    )


async def describe_all(
    hub,
    ctx,
    resource_identifier: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of resources (for example, DB instances) that have at least one pending maintenance action.

    Args:
        resource_identifier(str, optional): The ARN of a resource to return pending maintenance actions for. Defaults to None.
        filters(List, optional): A filter that specifies one or more resources to return pending maintenance actions for. Supported filters:    db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list will only include pending maintenance actions for the DB clusters identified by these ARNs.    db-instance-id - Accepts DB instance identifiers and DB instance ARNs. The results list will only include pending maintenance actions for the DB instances identified by these ARNs.  . Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribePendingMaintenanceActions request. If this parameter is specified, the response includes only records beyond the marker, up to a number of records specified by MaxRecords. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.pending_maintenance_action.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.pending_maintenance_action.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_pending_maintenance_actions",
        op_kwargs={
            "ResourceIdentifier": resource_identifier,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of bulk deployments.

    Args:
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.bulk_deployment.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.bulk_deployment.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_bulk_deployments",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(
    hub,
    ctx,
    execution_role_arn: str,
    input_file_uri: str,
    amzn_client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploys multiple groups in one operation. This action starts the bulk deployment of a specified set of group versions. Each group version deployment will be triggered with an adaptive rate that has a fixed upper limit. We recommend that you include an ''X-Amzn-Client-Token'' token in every ''StartBulkDeployment'' request. These requests are idempotent with respect to the token and the request parameters.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        execution_role_arn(str): The ARN of the execution role to associate with the bulk deployment operation. This IAM role must allow the ''greengrass:CreateDeployment'' action for all group versions that are listed in the input file. This IAM role must have access to the S3 bucket containing the input file.
        input_file_uri(str): The URI of the input file contained in the S3 bucket. The execution role must have ''getObject'' permissions on this bucket to access the input file. The input file is a JSON-serialized, line delimited file with UTF-8 encoding that provides a list of group and version IDs and the deployment type. This file must be less than 100 MB. Currently, AWS IoT Greengrass supports only ''NewDeployment'' deployment types.
        tags(Dict, optional): Tag(s) to add to the new resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.bulk_deployment.init.start(
                ctx, execution_role_arn=value, input_file_uri=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.bulk_deployment.init.start execution_role_arn=value, input_file_uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="start_bulk_deployment",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "ExecutionRoleArn": execution_role_arn,
            "InputFileUri": input_file_uri,
            "tags": tags,
        },
    )


async def stop(hub, ctx, bulk_deployment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the execution of a bulk deployment. This action returns a status of ''Stopping'' until the deployment is stopped. You cannot start a new bulk deployment while a previous deployment is in the ''Stopping'' state. This action doesn't rollback completed deployments or cancel pending deployments.

    Args:
        bulk_deployment_id(str): The ID of the bulk deployment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.bulk_deployment.init.stop(
                ctx, bulk_deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.bulk_deployment.init.stop bulk_deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="stop_bulk_deployment",
        op_kwargs={"BulkDeploymentId": bulk_deployment_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    repository_name: str,
    tags: List = None,
    image_tag_mutability: str = None,
    image_scanning_configuration: Dict = None,
    encryption_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a repository. For more information, see Amazon ECR Repositories in the Amazon Elastic Container Registry User Guide.

    Args:
        repository_name(str): The name to use for the repository. The repository name may be specified on its own (such as nginx-web-app) or it can be prepended with a namespace to group the repository into a category (such as project-a/nginx-web-app).
        tags(List, optional): The metadata that you apply to the repository to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.
        image_tag_mutability(str, optional): The tag mutability setting for the repository. If this parameter is omitted, the default setting of MUTABLE will be used which will allow image tags to be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten. Defaults to None.
        image_scanning_configuration(Dict, optional): The image scanning configuration for the repository. This determines whether images are scanned for known vulnerabilities after being pushed to the repository. Defaults to None.
        encryption_configuration(Dict, optional): The encryption configuration for the repository. This determines how the contents of your repository are encrypted at rest. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.repository.init.create(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.repository.init.create repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="create_repository",
        op_kwargs={
            "repositoryName": repository_name,
            "tags": tags,
            "imageTagMutability": image_tag_mutability,
            "imageScanningConfiguration": image_scanning_configuration,
            "encryptionConfiguration": encryption_configuration,
        },
    )


async def delete(
    hub, ctx, repository_name: str, registry_id: str = None, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a repository. If the repository contains images, you must either delete all images in the repository or use the force option to delete the repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository to delete. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to delete.
        force(bool, optional):  If a repository contains images, forces the deletion. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.repository.init.delete(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.repository.init.delete repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="delete_repository",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "force": force,
        },
    )


async def describe_all(
    hub,
    ctx,
    registry_id: str = None,
    repository_names: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes image repositories in a registry.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repositories to be described. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_names(List, optional): A list of repositories to describe. If this parameter is omitted, then all repositories in a registry are described. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeRepositories request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. This option cannot be used when you specify repositories with repositoryNames.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of repository results returned by DescribeRepositories in paginated output. When this parameter is used, DescribeRepositories only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeRepositories request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeRepositories returns up to 100 results and a nextToken value, if applicable. This option cannot be used when you specify repositories with repositoryNames. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.repository.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.repository.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="describe_repositories",
        op_kwargs={
            "registryId": registry_id,
            "repositoryNames": repository_names,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(hub, ctx, administrator_id: str, invitation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts the invitation to be a member account and be monitored by the Security Hub administrator account that the invitation was sent from. This operation is only used by member accounts that are not added through Organizations. When the member account accepts the invitation, permission is granted to the administrator account to view findings generated in the member account.

    Args:
        administrator_id(str): The account ID of the Security Hub administrator account that sent the invitation.
        invitation_id(str): The identifier of the invitation sent from the Security Hub administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.administrator.invitation.accept(
                ctx, administrator_id=value, invitation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.administrator.invitation.accept administrator_id=value, invitation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="accept_administrator_invitation",
        op_kwargs={"AdministratorId": administrator_id, "InvitationId": invitation_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, connection_input: Dict, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a connection definition in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which to create the connection. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        connection_input(Dict): A ConnectionInput object defining the connection to create.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.connection.create(ctx, connection_input=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.connection.create connection_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_connection",
        op_kwargs={"CatalogId": catalog_id, "ConnectionInput": connection_input},
    )


async def delete(hub, ctx, connection_name: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a connection from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        connection_name(str): The name of the connection to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.connection.delete(ctx, connection_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.connection.delete connection_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_connection",
        op_kwargs={"CatalogId": catalog_id, "ConnectionName": connection_name},
    )


async def get(
    hub, ctx, name: str, catalog_id: str = None, hide_password: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a connection definition from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        name(str): The name of the connection definition to retrieve.
        hide_password(bool, optional): Allows you to retrieve the connection metadata without returning the password. For instance, the AWS Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.connection.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.connection.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_connection",
        op_kwargs={
            "CatalogId": catalog_id,
            "Name": name,
            "HidePassword": hide_password,
        },
    )


async def get_all(
    hub,
    ctx,
    catalog_id: str = None,
    filter_: Dict = None,
    hide_password: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of connection definitions from the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        filter_(Dict, optional): A filter that controls which connections are returned. Defaults to None.
        hide_password(bool, optional): Allows you to retrieve the connection metadata without returning the password. For instance, the AWS Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.
        max_results(int, optional): The maximum number of connections to return in one response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.connection.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.connection.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_connections",
        op_kwargs={
            "CatalogId": catalog_id,
            "Filter": filter_,
            "HidePassword": hide_password,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, name: str, connection_input: Dict, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a connection definition in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        name(str): The name of the connection definition to update.
        connection_input(Dict): A ConnectionInput object that redefines the connection in question.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.connection.update(ctx, name=value, connection_input=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.connection.update name=value, connection_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_connection",
        op_kwargs={
            "CatalogId": catalog_id,
            "Name": name,
            "ConnectionInput": connection_input,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, domain: str, repository: str, format_: str, domain_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the endpoint of a repository for a specific package format. A repository has one endpoint for each package format:     npm     pypi     maven

    Args:
        domain(str):  The name of the domain that contains the repository. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain that contains the repository. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository. .
        format_(str):  Returns which endpoint of a repository to return. A repository has one endpoint for each package format:     npm     pypi     maven   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.repository.endpoint.get(
                ctx, domain=value, repository=value, format_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.repository.endpoint.get domain=value, repository=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="get_repository_endpoint",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "format": format_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, config_rule_names: List = None, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns status information for each of your AWS managed Config rules. The status includes information such as the last time AWS Config invoked the rule, the last time AWS Config failed to invoke the rule, and the related error for the last failure.

    Args:
        config_rule_names(List, optional): The name of the AWS managed Config rules for which you want status information. If you do not specify any names, AWS Config returns status information for all AWS managed Config rules that you use. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.
        limit(int, optional): The number of rule evaluation results that you want returned. This parameter is required if the rule limit for your account is more than the default of 150 rules. For information about requesting a rule limit increase, see AWS Config Limits in the AWS General Reference Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.rule.evaluation.status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.rule.evaluation.status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_config_rule_evaluation_status",
        op_kwargs={
            "ConfigRuleNames": config_rule_names,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    arn: str = None,
    type_: str = None,
    type_name: str = None,
    version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Specify the default version of an extension. The default version of an extension will be used in CloudFormation operations.

    Args:
        arn(str, optional): The Amazon Resource Name (ARN) of the extension for which you want version summary information. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_(str, optional): The kind of extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        version_id(str, optional): The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.default_version.set(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.default_version.set
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="set_type_default_version",
        op_kwargs={
            "Arn": arn,
            "Type": type_,
            "TypeName": type_name,
            "VersionId": version_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns tags for a resource. Tagging is currently supported only for directories with a limit of 50 tags per directory. All 50 tags are returned for a given directory with this API call.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource. Tagging is only supported for directories.
        next_token(str, optional): The pagination token. This is for future use. Currently pagination is not supported for tagging. Defaults to None.
        max_results(int, optional): The MaxResults parameter sets the maximum number of results returned in a single page. This is for future use and is not supported currently. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_tags_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def generate(
    hub,
    ctx,
    aws_account_id: str,
    namespace: str,
    authorized_resource_arns: List,
    experience_configuration: Dict,
    session_lifetime_in_minutes: int = None,
    session_tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates an embed URL that you can use to embed an Amazon QuickSight dashboard in your website, without having to register any reader users. Before you use this action, make sure that you have configured the dashboards and permissions. The following rules apply to the generated URL:   It contains a temporary bearer token. It is valid for 5 minutes after it is generated. Once redeemed within this period, it cannot be re-used again.   The URL validity period should not be confused with the actual session lifetime that can be customized using the  SessionLifetimeInMinutes  parameter. The resulting user session is valid for 15 minutes (default) to 10 hours (maximum).   You are charged only when the URL is used or there is interaction with Amazon QuickSight.   For more information, see Embedded Analytics in the Amazon QuickSight User Guide. For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon QuickSight Developer Portal.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account that contains the dashboard that you're embedding.
        session_lifetime_in_minutes(int, optional): How many minutes the session is valid. The session lifetime must be in [15-600] minutes range. Defaults to None.
        namespace(str): The Amazon QuickSight namespace that the anonymous user virtually belongs to. If you are not using an Amazon QuickSight custom namespace, set this to default.
        session_tags(List, optional): The session tags used for row-level security. Before you use this parameter, make sure that you have configured the relevant datasets using the DataSet$RowLevelPermissionTagConfiguration parameter so that session tags can be used to provide row-level security. These are not the tags used for the Amazon Web Services resource tagging feature. For more information, see Using Row-Level Security (RLS) with Tags. Defaults to None.
        authorized_resource_arns(List): The Amazon Resource Names for the Amazon QuickSight resources that the user is authorized to access during the lifetime of the session. If you choose Dashboard embedding experience, pass the list of dashboard ARNs in the account that you want the user to be able to view.
        experience_configuration(Dict): The configuration of the experience you are embedding.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.embed_url_for_.anonymous_user.generate(
                ctx,
                aws_account_id=value,
                namespace=value,
                authorized_resource_arns=value,
                experience_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.embed_url_for_.anonymous_user.generate aws_account_id=value, namespace=value, authorized_resource_arns=value, experience_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="generate_embed_url_for_anonymous_user",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "SessionLifetimeInMinutes": session_lifetime_in_minutes,
            "Namespace": namespace,
            "SessionTags": session_tags,
            "AuthorizedResourceArns": authorized_resource_arns,
            "ExperienceConfiguration": experience_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(hub, ctx, rest_api_id: str, location: Dict, properties: str) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        location(Dict): [Required] The location of the targeted API entity of the to-be-created documentation part.
        properties(str): [Required] The new documentation content map of the targeted API entity. Enclosed key-value pairs are API-specific, but only OpenAPI-compliant key-value pairs can be exported and, hence, published.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.create(ctx, rest_api_id=value, location=value, properties=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.create rest_api_id=value, location=value, properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_documentation_part",
        op_kwargs={
            "restApiId": rest_api_id,
            "location": location,
            "properties": properties,
        },
    )


async def delete(hub, ctx, rest_api_id: str, documentation_part_id: str) -> None:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_part_id(str): [Required] The identifier of the to-be-deleted documentation part.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.delete(ctx, rest_api_id=value, documentation_part_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.delete rest_api_id=value, documentation_part_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_documentation_part",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationPartId": documentation_part_id,
        },
    )


async def get(hub, ctx, rest_api_id: str, documentation_part_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_part_id(str): [Required] The string identifier of the associated RestApi.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.get(ctx, rest_api_id=value, documentation_part_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.get rest_api_id=value, documentation_part_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_documentation_part",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationPartId": documentation_part_id,
        },
    )


async def get_all(
    hub,
    ctx,
    rest_api_id: str,
    type_: str = None,
    name_query: str = None,
    path: str = None,
    position: str = None,
    limit: int = None,
    location_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        type_(str, optional): The type of API entities of the to-be-retrieved documentation parts. . Defaults to None.
        name_query(str, optional): The name of API entities of the to-be-retrieved documentation parts. Defaults to None.
        path(str, optional): The path of API entities of the to-be-retrieved documentation parts. Defaults to None.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.
        location_status(str, optional): The status of the API documentation parts to retrieve. Valid values are DOCUMENTED for retrieving DocumentationPart resources with content and UNDOCUMENTED for DocumentationPart resources without content. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_documentation_parts",
        op_kwargs={
            "restApiId": rest_api_id,
            "type": type_,
            "nameQuery": name_query,
            "path": path,
            "position": position,
            "limit": limit,
            "locationStatus": location_status,
        },
    )


async def import_(
    hub,
    ctx,
    rest_api_id: str,
    body: bytes,
    mode: str = None,
    fail_on_warnings: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        mode(str, optional): A query parameter to indicate whether to overwrite (OVERWRITE) any existing DocumentationParts definition or to merge (MERGE) the new definition into the existing one. The default value is MERGE. Defaults to None.
        fail_on_warnings(bool, optional): A query parameter to specify whether to rollback the documentation importation (true) or not (false) when a warning is encountered. The default value is false. Defaults to None.
        body(bytes): [Required] Raw byte array representing the to-be-imported documentation parts. To import from an OpenAPI file, this is a JSON object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.import(ctx, rest_api_id=value, body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.import rest_api_id=value, body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="import_documentation_parts",
        op_kwargs={
            "restApiId": rest_api_id,
            "mode": mode,
            "failOnWarnings": fail_on_warnings,
            "body": body,
        },
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    documentation_part_id: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_part_id(str): [Required] The identifier of the to-be-updated documentation part.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.part.update(ctx, rest_api_id=value, documentation_part_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.part.update rest_api_id=value, documentation_part_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_documentation_part",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationPartId": documentation_part_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, repository_name: str, image_ids: List, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a list of specified images within a repository in a public registry. Images are specified with either an imageTag or imageDigest. You can remove a tag from an image by specifying the image's tag in your request. When you remove the last tag from an image, the image is deleted from your repository. You can completely delete an image (and all of its tags) by specifying the image's digest in your request.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the image to delete. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The repository in a public registry that contains the image to delete.
        image_ids(List): A list of image ID references that correspond to images to delete. The format of the imageIds reference is imageTag=tag or imageDigest=digest.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.delete_image.batch(
                ctx, repository_name=value, image_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.delete_image.batch repository_name=value, image_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="batch_delete_image",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageIds": image_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the tags associated with the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each AWS resource, up to 50 tags for a resource. You can tag the AWS resources that you manage through AWS Network Firewall: firewalls, firewall policies, and rule groups.

    Args:
        next_token(str, optional): When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request. Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="list_tags_for_resource",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ResourceArn": resource_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, assessment_template_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts the generation of an exclusions preview for the specified assessment template. The exclusions preview lists the potential exclusions (ExclusionPreview) that Inspector can detect before it runs the assessment.

    Args:
        assessment_template_arn(str): The ARN that specifies the assessment template for which you want to create an exclusions preview.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.exclusion.preview.create(
                ctx, assessment_template_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.exclusion.preview.create assessment_template_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="create_exclusions_preview",
        op_kwargs={"assessmentTemplateArn": assessment_template_arn},
    )


async def get(
    hub,
    ctx,
    assessment_template_arn: str,
    preview_token: str,
    next_token: str = None,
    max_results: int = None,
    locale: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token. You can obtain the preview token by running the CreateExclusionsPreview API.

    Args:
        assessment_template_arn(str): The ARN that specifies the assessment template for which the exclusions preview was requested.
        preview_token(str): The unique identifier associated of the exclusions preview.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the GetExclusionsPreviewRequest action. Subsequent calls to the action fill nextToken in the request with the value of nextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 100. The maximum value is 500. Defaults to None.
        locale(str, optional): The locale into which you want to translate the exclusion's title, description, and recommendation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.exclusion.preview.get(
                ctx, assessment_template_arn=value, preview_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.exclusion.preview.get assessment_template_arn=value, preview_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="get_exclusions_preview",
        op_kwargs={
            "assessmentTemplateArn": assessment_template_arn,
            "previewToken": preview_token,
            "nextToken": next_token,
            "maxResults": max_results,
            "locale": locale,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    license_arn: str,
    license_name: str,
    product_name: str,
    issuer: Dict,
    home_region: str,
    validity: Dict,
    entitlements: List,
    consumption_configuration: Dict,
    status: str,
    client_token: str,
    license_metadata: List = None,
    source_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of the specified license.

    Args:
        license_arn(str): Amazon Resource Name (ARN) of the license.
        license_name(str): License name.
        product_name(str): Product name.
        issuer(Dict): License issuer.
        home_region(str): Home Region of the license.
        validity(Dict): Date and time range during which the license is valid, in ISO8601-UTC format.
        license_metadata(List, optional): Information about the license. Defaults to None.
        entitlements(List): License entitlements.
        consumption_configuration(Dict): Configuration for consumption of the license. Choose a provisional configuration for workloads running with continuous connectivity. Choose a borrow configuration for workloads with offline usage.
        status(str): License status.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        source_version(str, optional): Current version of the license. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.version.create(
                ctx,
                license_arn=value,
                license_name=value,
                product_name=value,
                issuer=value,
                home_region=value,
                validity=value,
                entitlements=value,
                consumption_configuration=value,
                status=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.version.create license_arn=value, license_name=value, product_name=value, issuer=value, home_region=value, validity=value, entitlements=value, consumption_configuration=value, status=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="create_license_version",
        op_kwargs={
            "LicenseArn": license_arn,
            "LicenseName": license_name,
            "ProductName": product_name,
            "Issuer": issuer,
            "HomeRegion": home_region,
            "Validity": validity,
            "LicenseMetadata": license_metadata,
            "Entitlements": entitlements,
            "ConsumptionConfiguration": consumption_configuration,
            "Status": status,
            "ClientToken": client_token,
            "SourceVersion": source_version,
        },
    )


async def list_all(
    hub, ctx, license_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all versions of the specified license.

    Args:
        license_arn(str): Amazon Resource Name (ARN) of the license.
        next_token(str, optional): Token for the next set of results. Defaults to None.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.version.list_all(
                ctx, license_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.version.list_all license_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_license_versions",
        op_kwargs={
            "LicenseArn": license_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, application_name: str, revision: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an application revision.

    Args:
        application_name(str): The name of the application that corresponds to the revision.
        revision(Dict): Information about the application revision to get, including type and location.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.revision.get(
                ctx, application_name=value, revision=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.revision.get application_name=value, revision=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_application_revision",
        op_kwargs={"applicationName": application_name, "revision": revision},
    )


async def list_all(
    hub,
    ctx,
    application_name: str,
    sort_by: str = None,
    sort_order: str = None,
    s3_bucket: str = None,
    s3_key_prefix: str = None,
    deployed: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about revisions for an application.

    Args:
        application_name(str):  The name of an AWS CodeDeploy application associated with the IAM user or AWS account. .
        sort_by(str, optional): The column name to use to sort the list results:    registerTime: Sort by the time the revisions were registered with AWS CodeDeploy.    firstUsedTime: Sort by the time the revisions were first used in a deployment.    lastUsedTime: Sort by the time the revisions were last used in a deployment.    If not specified or set to null, the results are returned in an arbitrary order. . Defaults to None.
        sort_order(str, optional):  The order in which to sort the list results:     ascending: ascending order.    descending: descending order.   If not specified, the results are sorted in ascending order. If set to null, the results are sorted in an arbitrary order. Defaults to None.
        s3_bucket(str, optional):  An Amazon S3 bucket name to limit the search for revisions.   If set to null, all of the user's buckets are searched. . Defaults to None.
        s3_key_prefix(str, optional):  A key prefix for the set of Amazon S3 objects to limit the search for revisions. . Defaults to None.
        deployed(str, optional):  Whether to list revisions based on whether the revision is the target revision of a deployment group:     include: List revisions that are target revisions of a deployment group.    exclude: Do not list revisions that are target revisions of a deployment group.    ignore: List all revisions.  . Defaults to None.
        next_token(str, optional): An identifier returned from the previous ListApplicationRevisions call. It can be used to return the next set of applications in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.revision.list_all(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.revision.list_all application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_application_revisions",
        op_kwargs={
            "applicationName": application_name,
            "sortBy": sort_by,
            "sortOrder": sort_order,
            "s3Bucket": s3_bucket,
            "s3KeyPrefix": s3_key_prefix,
            "deployed": deployed,
            "nextToken": next_token,
        },
    )


async def register(
    hub, ctx, application_name: str, revision: Dict, description: str = None
) -> None:
    r"""
    **Autogenerated function**

    Registers with AWS CodeDeploy a revision for the specified application.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        description(str, optional): A comment about the revision. Defaults to None.
        revision(Dict): Information about the application revision to register, including type and location.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.application.revision.register(
                ctx, application_name=value, revision=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.application.revision.register application_name=value, revision=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="register_application_revision",
        op_kwargs={
            "applicationName": application_name,
            "description": description,
            "revision": revision,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def remove(hub, ctx, app_id: str, clean_amplify_app: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes all backend environments from your Amplify project.

    Args:
        app_id(str): The app ID.
        clean_amplify_app(bool, optional): Cleans up the Amplify Console app if this value is set to true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.all_backend.remove(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.all_backend.remove app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="remove_all_backends",
        op_kwargs={"AppId": app_id, "CleanAmplifyApp": clean_amplify_app},
    )
